# Control

::: inspeqtor.control

::: inspeqtor.control.BaseControl

::: inspeqtor.control.ControlSequence

::: inspeqtor.control.control_waveform

::: inspeqtor.control.sequence_waveform

::: inspeqtor.control.ravel_unravel_fn

::: inspeqtor.control.sample_params

::: inspeqtor.control.construct_control_sequence_reader

::: inspeqtor.control.ravel_transform

::: inspeqtor.control.ParametersDictType

::: inspeqtor.control.nested_sample

::: inspeqtor.control.check_bounds

::: inspeqtor.control.merge_lower_upper

::: inspeqtor.control.split_bounds

::: inspeqtor.control.get_envelope

::: inspeqtor.control.envelope_fn

## Library

::: inspeqtor.control.library

::: inspeqtor.control.library.DragPulse

::: inspeqtor.control.library.DragPulseV2

::: inspeqtor.control.library.MultiDragPulseV3

::: inspeqtor.control.library.GaussianPulse

::: inspeqtor.control.library.TwoAxisGaussianPulse

::: inspeqtor.control.library.gaussian_envelope

::: inspeqtor.control.library.polynomial_feature_map

::: inspeqtor.control.library.predefined_controls

::: inspeqtor.control.library.default_control_reader

::: inspeqtor.control.library.get_drag_pulse_v2_sequence

::: inspeqtor.control.library.drag_feature_map
